<?php

namespace Drp\Logger\Listeners;

use Drp\Logger\Logger;
use Illuminate\Http\Request;

abstract class Listener
{
    /**
     * @var \Illuminate\Http\Request
     */
    protected $request;

    /**
     * Listener constructor.
     *
     * @param \Illuminate\Http\Request $request
     */
    public function __construct(Request $request)
    {
        $this->request = $request;
    }

    /**
     * Determines whether the type is enabled, defaults to true.
     *
     * @param $type
     * @return bool
     */
    public function enabled($type)
    {
        return is_null(config('logger.log.' . $type)) ? true : config('logger.log.' . $type);
    }

    /**
     * @return \Illuminate\Http\Request
     */
    public function request()
    {
        return $this->request;
    }

    /**
     * Adds the request data to the passed data and log.
     *
     * @param array $data
     * @param null $type
     */
    public function log(array $data, $type = null)
    {
        $data = array_add($data, 'request', $this->formatRequest($this->request()));

        (new Logger)->log($data, $type);
    }

    /**
     * Formats the Request into a readable format.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    protected function formatRequest(Request $request)
    {
        return [
            'ip' => $request->ip(),
            'ips' => $request->ips(),
            'header' => $request->header(),
            'server' => $request->server(),
            'old' => $request->old(),
            'cookie' => $request->cookie(),
            'secure' => $request->secure(),
            'method' => $request->method(),
            'root' => $request->root(),
            'url' => $request->url(),
            'fullUrl' => $request->fullUrl(),
            'path' => $request->path(),
            'decodedPath' => $request->decodedPath(),
            'bearerToken' => $request->bearerToken(),
        ];
    }
}
