<?php

namespace Drp\Logger;

use Illuminate\Contracts\Events\Dispatcher as DispatcherContract;
use Illuminate\Foundation\Support\Providers\EventServiceProvider as ServiceProvider;

class LoggerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * The event listener mappings for the application.
     *
     * @var array
     */
    protected $listen = [
        'Illuminate\Mail\Events\MessageSending' => [
            'Drp\Logger\Listeners\MailListener',
        ],
        'Drp\Logger\Events\ValidationErrorWasDetected' => [
            'Drp\Logger\Listeners\ValidationListener',
        ],
    ];

    /**
     * Register any other events for your application.
     *
     * @param  \Illuminate\Contracts\Events\Dispatcher  $events
     * @return void
     */
    public function boot(DispatcherContract $events)
    {
        parent::boot($events);

        $this->publishConfig();
        $this->publishMigrations();
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->app->bind(
            'logger',
            'Drp\Logger\Logger'
        );
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return [];
    }

    /**
     * Publish the config.
     */
    private function publishConfig()
    {
        $this->publishes([
            __DIR__.'/../../config/logger.php' => config_path('logger.php'),
        ], 'config');
    }

    /**
     *  Publish the migrations.
     */
    private function publishMigrations()
    {
        $timestamp = date('Y_m_d_His', time());
        $this->publishes([
            __DIR__.'/../../migrations/create_logs_table.stub' => database_path('/migrations/' . $timestamp . '_create_logs_table.php'),
        ], 'migrations');
    }
}
